Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2561)

Unified Diff: third_party/WebKit/Source/modules/quota/StorageManager.cpp

Issue 1373773003: Implement 'window.isSecureContext'. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: document. Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/quota/StorageManager.cpp
diff --git a/third_party/WebKit/Source/modules/quota/StorageManager.cpp b/third_party/WebKit/Source/modules/quota/StorageManager.cpp
index ab2734a117c27732990ab1f08b413f2807299669..051927dc290fdc3116bec3725d26f99910a1e100 100644
--- a/third_party/WebKit/Source/modules/quota/StorageManager.cpp
+++ b/third_party/WebKit/Source/modules/quota/StorageManager.cpp
@@ -79,14 +79,14 @@ ScriptPromise StorageManager::requestPersistent(ScriptState* scriptState)
ExecutionContext* executionContext = scriptState->executionContext();
SecurityOrigin* securityOrigin = executionContext->securityOrigin();
// TODO(dgrogan): Is the isUnique() check covered by the later
// isPrivilegedContext() check? If so, maybe remove it. Write a test if it
// stays.
if (securityOrigin->isUnique()) {
resolver->reject(DOMException::create(NotSupportedError));
return promise;
}
String errorMessage;
- if (!executionContext->isPrivilegedContext(errorMessage)) {
+ if (!executionContext->isSecureContext(errorMessage)) {
resolver->reject(DOMException::create(SecurityError, errorMessage));
return promise;
}
@@ -79,14 +79,14 @@ ScriptPromise StorageManager::requestPersistent(ScriptState* scriptState)
SecurityOrigin* securityOrigin = executionContext->securityOrigin();
// TODO(dgrogan): Is the isUnique() check covered by the later
- // isPrivilegedContext() check? If so, maybe remove it. Write a test if it
+ // isSecureContext() check? If so, maybe remove it. Write a test if it
// stays.
if (securityOrigin->isUnique()) {

Powered by Google App Engine
This is Rietveld 408576698